#ifndef HecEvent_h
#define HecEvent_h

#include <vector>
#include "HecCell.h"
#include "Geometry.h"

/*!  - Class HecEvent
  * - Author: Ian Gable (igable@uvic.ca)
  * - Date:  05/10/2002
  * - Description: HecEvent stores a list of HecCells in a vector. Each HecCell can be retrieved.
  */
class HecEvent{

 public:
  /** The default contructor
    */
  HecEvent();

  /** Add adcValue to hecCell with adcNumber
    * @param cell a static HecCell Class
    */
  bool addHecCell(HecCell cell);

  /** Return a pointer to hec Cell with adcNumber
    * @param   acdNumber The acd Number of the cell you wish to return
    */
  HecCell* hecCell(int adcNumber);

   //! clear the content of the cells so that  new info can be loaded
  void clearCells();

  //! return the number of cells
  int numCells();

  // ! return a constant pointer to the m_hecCells vector
  const vector<HecCell>* hecCellsPointer();

  //! get event number
  int eventNumber() { return m_eventNumber; };

  //! set event number
  void eventNumber(int eventNum) {m_eventNumber = eventNum;};

  /** Set the hecTrigger. Note that the parameter MUST be an array of
    * 5 integers.
    * @param hecTriggerArray a pointer to the hecTriggerArray
    */
  void setHecTrigger(unsigned int hecTriggerArray[5]);

  //! Return a pointer to the HecTriggerVector
  vector<int>* getHecTriggerVector(){ return &m_hecTriggerVector;};

  //! Returns true when particle has contancted both muon detectors
  bool isMuon() { return m_isMuon;}

  //! Returns true when event is a Random Trigger
  bool isRandom() { return m_isRandom;}

  /** Get the trigger bit from 0 to 4
    * (physics,electron,pion,muon,random)
    * @param bit The trigger bit 0-4 will cause exit(1) if accessed outside
    */
  int getTriggerBit(int bit);

  //maybe include method to get individual elements of the Trigger Vector

 private:
  vector<HecCell> m_cellVector; //! contains an array of cells
  void processTrigger();

  int m_eventNumber; //! the event number
  vector<int> m_hecTriggerVector; //! vector of the trigger information
  bool m_isMuon;
  bool m_isRandom;

};
#endif
