#ifndef HecGeometry_h
#define HecGeometry_h

#include <string>
#include <vector>
#include <iostream>

#define MAX_CELLS  600 //what to do here?
/*! -Class:    HecGeometry
  - Author:   Ian Gable (igable@uvic.ca)
  - Date:      05/09/2002
  - Description: HecGeometry can be used to determine the z, eta, and phi coords given
                        a particular  adcNumber. It reads a specific geometry file of a specific format
                        which is passed to the class in the constructor.
  - Notes:           This class will not operate properly if the file format is changed.
*/

using std::vector;
using std::string;
using std::cout;
using std::endl;

class HecGeometry {

 public:

  /** Contructor
    * @param geoFileName The name of the Geometry File. Can be relative or absolute path
    */
  HecGeometry(string geoFileName);

  //! get the integer eta Coord
  int iEta(int adcNumber);

  //! get the integer phi coordinate
  int iPhi(int adcNumber);

  //! get the integer Z coordinate
  int iZ(int adcNumber);

  /**  Return a vector containing a list of the acdNumber for the given cordinate range.
    * Rememeber that you can use all the propertes of STL vectors.
    */
  vector<int> adcNumbers(int etaStart, int etaFinish, int phiStart, int phiFinish, int zStart, int zFinish);

 private:

  void loadGeometryFile(string geoFileName); //this will load the geometry file

  int m_eta[MAX_CELLS]; //eta (pseudorapidity) aranged according to acd number
  int m_phi[MAX_CELLS]; //phi according to acd number
  int m_z[MAX_CELLS];   //z according to acd number
  int m_numCells; // the number of cells according to the file


};

#endif
