


#include "HecGeometry.h"
#include <fstream>


using std::ifstream;

HecGeometry::HecGeometry(string geoFileName){

  //initialize our arrays with a easily
  //recognizable value
  for(int i =0; i < MAX_CELLS; i++){
    m_eta[i] = 999;
    m_z[i] = 999;
    m_phi[i] =999;
  }
 
  loadGeometryFile(geoFileName);

}



int HecGeometry::iEta(int adcNumber){
  if(adcNumber >= 1 && adcNumber <= m_numCells){
    return m_eta[adcNumber-1];
  } else {
    cout << "Eta index accesses outside of bounds at: " << adcNumber << endl;
    exit(1);
  }
}

int HecGeometry::iPhi(int adcNumber){
  if(adcNumber >=1 && adcNumber <= m_numCells){
    return m_phi[adcNumber-1];
  } else {
    cout << "Phi index accesses outside of bounds at: " << adcNumber << endl;
    exit(1);
  }
}

int HecGeometry::iZ(int adcNumber){
  if(adcNumber >=1 && adcNumber <= m_numCells){
    return m_z[adcNumber-1];
  } else {
    cout << "Z index accesses outside of bounds at: " << adcNumber << endl;
    exit(1);
  }
}

vector<int> HecGeometry::adcNumbers(int etaStart, int etaFinish, int phiStart, int phiFinish, int zStart, int zFinish){
  vector<int> adc;
  for(int i =0; i < m_numCells; i++){
    if(m_eta[i] >= etaStart &&m_eta[i] <= etaFinish &&
       m_phi[i] >= phiStart && m_phi[i] <= phiFinish &&
       m_z[i] >= zStart && m_z[i] <= zFinish) {
        adc.push_back(i+1);
    }
  }
  return adc;
}


void HecGeometry::loadGeometryFile(string geoFileName)
{

  ifstream fStream(geoFileName.c_str());// open the file stream

  // exit of we have the wrong file name
  if(!fStream.is_open()){
    cout << "Failed to open file:" << geoFileName << endl;
    exit(1);
  }

 //parse the file
  int i = 0;
  char firstChar[4]; //first 3 Characters
  char garbage[200]; //holds discarded lines
  int junk;          //holds discarded numbers
  string firstString;//used to make comparison easier

  fStream.get(firstChar,4);// Get the first characters
  
  while(!fStream.eof() ){

    

    firstString = firstChar;

    //dump all comment lines else process them

    if(firstString == "###" || firstString == "geo" ){
      fStream.getline(garbage,1000);
      fStream.get(firstChar,4);

    } else {
    fStream >> junk >> junk >> m_z[i] >> m_eta[i] >> m_phi[i] >> junk >> junk;
    //cout << " Z: " << m_z[i] << " Eta: " << m_eta[i] << " Phi: " << m_phi[i] << endl;
    i++;
    }
 
   
  }
  m_numCells = i; // numbered starting from 1
  fStream.close();
}

